@@ -149,7 +149,7 @@ class Queue:
     job = self.collection.find_one_and_update(query, {"$set": {"inProgress": True, "startedAt": datetime.utcnow()}}, sort=[("priority", DESCENDING), ("createdAt", ASCENDING)])
 
     if not job is None:
-      keys = ["depends_on", "result_ttl", "failure_ttl", "ttl", "createdAt", "lang"]
+      keys = ["depends_on", "result_ttl", "failure_ttl", "ttl", "createdAt", "lang", "channel"]
       kwargs = {}
       for k in keys:
         if k in job:
